@@ -267,6 +267,8 @@ public:
     void setPausingOnMeteredConnection(bool pausingOnMeteredConnection);
     bool isInsecure() const;
     void setInsecure(bool insecure);
+    std::optional<QSet<QString>> &dirFilter();
+    std::optional<QSet<QString>> &devFilter();
 
     // getter for information retrieved from Syncthing
     const QString &configDir() const;
@@ -481,9 +483,9 @@ private Q_SLOTS:
     void continueReconnecting();
     void autoReconnect();
     bool setStatus(Data::SyncthingStatus status);
-    void emitError(const QString &message, const QJsonParseError &jsonError, QNetworkReply *reply, const QByteArray &response = QByteArray());
-    void emitError(const QString &message, Data::SyncthingErrorCategory category, QNetworkReply *reply);
-    void emitError(const QString &message, QNetworkReply *reply);
+    void emitError(const QString &message, const QJsonParseError &jsonError, QNetworkReply *reply, const QByteArray &response);
+    void emitError(const QString &message, Data::SyncthingErrorCategory category, QNetworkReply *reply, const QByteArray &response);
+    void emitError(const QString &message, QNetworkReply *reply, const QByteArray &response);
     void emitMyIdChanged(const QString &newId);
     void emitTildeChanged(const QString &newTilde, const QString &newPathSeparator);
     void handleFatalConnectionError();
@@ -560,6 +562,8 @@ private:
     SyncthingEventId m_lastEventId;
     SyncthingEventId m_lastDiskEventId;
     QHash<QString, SyncthingEventId> m_lastEventIdByMask;
+    std::optional<QSet<QString>> m_dirFilter;
+    std::optional<QSet<QString>> m_devFilter;
     QTimer m_trafficPollTimer;
     QTimer m_devStatsPollTimer;
     QTimer m_errorsPollTimer;
@@ -1024,6 +1028,24 @@ inline void SyncthingConnection::setInsecure(bool insecure)
     m_insecure = insecure;
 }
 
+/*!
+ * \brief Returns the directory filter; if set, the completion will only be requested for the dirs with
+ *        IDs contained by the assigned filter set.
+ */
+inline std::optional<QSet<QString>> &SyncthingConnection::dirFilter()
+{
+    return m_dirFilter;
+}
+
+/*!
+ * \brief Returns the device filter; if set, the completion will only be requested for the devs with
+ *        IDs contained by the assigned filter set.
+ */
+inline std::optional<QSet<QString>> &SyncthingConnection::devFilter()
+{
+    return m_devFilter;
+}
+
 /*!
  * \brief Returns what information is considered to compute the overall status returned by status().
  */
